<?php

App::uses('AppShell', 'Console/Command');

App::uses('Controller', 'Controller');
App::uses('ComponentCollection', 'Controller');
App::uses('AclComponent', 'Controller/Component');

class EvImpersonatePermissionsShell extends AppShell {

/**
 * Root node name.
 *
 * @var string
 **/
	public $rootNode = 'impersonations';

/**
 * Internal Clean Actions switch
 *
 * @var bool
 **/
	protected $_clean = false;

/**
 * Start up And load Acl Component / Aco model
 *
 * @param Controller $controller The controller to use to check for permissions.
 * @return void
 **/
	public function startup($controller = null) {
		if (!$controller) {
			$controller = new Controller(new CakeRequest());
		}
		$collection = new ComponentCollection();
		$this->Acl = new AclComponent($collection);
		$this->Acl->startup($controller);
		$this->Aco = $this->Acl->Aco;
		$this->controller = $controller;
	}

/**
 * Sync the ACO table
 *
 * @param array $params The parameters to use to check for permissions.
 * @return void
 **/
	public function aco_sync($params = array()) {
		$this->_clean = true;
		$this->aco_update();
	}

/**
 * Updates the Aco Tree with new site setting categories and site settings.
 *
 * @return void
 **/
	public function aco_update() {
		$root = $this->_checkNode($this->rootNode, $this->rootNode, null);

		$this->out(__('<success>Aco Update Complete</success>'));
		return true;
	}

/**
 * Check a node for existance, create it if it doesn't exist.
 *
 * @param string $path The path to use to check for the node.
 * @param string $alias The alias of the node to create if the node is missing.
 * @param int $parentId The parent id to associate with this node.
 * @return array Aco Node array
 */
	protected function _checkNode($path, $alias, $parentId = null) {
		$node = $this->Aco->node($path);
		if (!$node) {
			$this->Aco->create(array('parent_id' => $parentId, 'model' => null, 'alias' => $alias));
			$node = $this->Aco->save();
			$node['Aco']['id'] = $this->Aco->id;
			$this->out(__('Created Aco node: <success>%s</success>', $path), 1, Shell::VERBOSE);
		} else {
			$node = $node[0];
		}
		return $node;
	}
}
